package
Version:
v0.0.0-...-dc902cf
Opens a new window with list of versions in this module.
Published: Mar 4, 2021
License: GPL-3.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type IO interface {
PrintMessage(message ...string)
GetRune() (rune, error)
}
IO is an interface for communication with user's input/output
NewIO is a factory method for creating console IO
Source Files
¶
Click to show internal directories.
Click to hide internal directories.